Creators class

Constructors

Creators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

path String
getter/setter pair

Static Methods

addForm({List<String>? fields, String? featureName, String? formName}) → void
addLang({List<String>? languages}) Future<void>
addPage({String? featureName, String? routeName}) Future<void>
createFeature({String? name, String? pageS}) → void
init({bool firebase = false, bool onboarding = false}) Future<void>